#### Part A - Use QGIS tool to add DIVISION property

1. Load districts shapefile (`.shp`) in QGIS tool
2. Click Layer on toolbar on top and select `Attribute Table`
3. Toggle editing mode (top left-most)
4. Click New Field option (4th from the right on the toolbar)
5. Name your new field
6. View and edit the new field by clicking on specific cells
7. Save and Export. On the bottom left of QGIS, in Layers Panel click `Save As`, choose a format of your choice.

#### Part B - Join layers using DIVISION property - mapshaper.org

1. Load the `GeoJSON` file from above in mapshaper.org
2. Enable information view (i icon on the right panel)
3. Enable console mode (click console on top right)
4. (Optional based on the `GeoJSON`) Filter specific fields - run this in console `filter-fields Id,State,ST_Name,DT_CODE,DT_NAME,DIVISION`
5. Merge district layers based on DIVISION name `dissolve2 fields=DIVISION copy-fields=Id,State,ST_Name`

Export this new file as `TopoJSON` and use.